@@ -1,5 +1,3 @@
-from confluent_kafka.cimpl import TopicPartition
-from scrapy import signals
 from scrapy.utils.misc import load_object
 
 from . import connection
@@ -70,15 +68,6 @@ class Scheduler(object):
     def open(self, spider):
         self.spider = spider
         self.settings = self.spider.settings
-        self.create_topic = self.settings.getbool('KAFKA_TOPIC_CREATE_AUTO', defaults.KAFKA_TOPIC_CREATE_AUTO)
-        if self.create_topic:
-            connection.create_topic_client(self.topic.format(self.spider.name),
-                                           bootstrap_servers=self.settings.get('KAFKA_DEFAULTS_HOST',
-                                                                               defaults.KAFKA_DEFAULTS_HOST),
-                                           partitions=self.settings.get('KAFKA_DEFAULTS_PARTITIONS',
-                                                                        defaults.KAFKA_DEFAULTS_PARTITIONS),
-                                           replication_factor=self.settings.get('KAFKA_DEFAULTS_REPLICATION',
-                                                                                defaults.KAFKA_DEFAULTS_REPLICATION))
         self.consumer = connection.create_consumer(self.settings.get('GROUP_ID', self.spider.name),
                                                    bootstrap_servers=self.settings.get('KAFKA_DEFAULTS_HOST',
                                                                                        defaults.KAFKA_DEFAULTS_HOST))
@@ -98,7 +87,7 @@ class Scheduler(object):
                 producer=self.producer,
                 consumer=self.consumer,
                 spider=spider,
-                topic=[self.settings.get('SPIDER_TOPIC' ,self.topic.format(self.spider.name))],
+                topic=[self.settings.get('SPIDER_TOPIC', self.topic.format(self.spider.name))],
                 serializer=self.serializer,
                 server=self.server
             )
