@@ -24,15 +24,6 @@ class Kafka_Scrapy_Mixin(object):
             pass
         else:
             self.kafka_topic = settings.get('START_TOPIC', self.kafka_topic.format(crawler.settings.get('BOT_NAME')))
-        self.create_topic = self.settings.getbool('KAFKA_START_TOPIC_CREATE_AUTO',
-                                                  defaults.KAFKA_START_TOPIC_CREATE_AUTO)
-        if self.create_topic:
-            connection.create_topic_client(self.kafka_topic, bootstrap_servers=settings.get('KAFKA_DEFAULTS_HOST',
-                                           defaults.KAFKA_DEFAULTS_HOST),
-                                           partitions=settings.get('KAFKA_DEFAULTS_START_PARTITIONS',
-                                           defaults.KAFKA_DEFAULTS_START_PARTITIONS),
-                                           replication_factor=settings.get('KAFKA_DEFAULTS_START_REPLICATION',
-                                           defaults.KAFKA_DEFAULTS_START_REPLICATION))
         self.consumer_ = connection.create_start_request_consumer(name=settings.get('KAFKA_START_GROUP', self.name),
                                                                   bootstrap_servers=settings.get('KAFKA_DEFAULTS_HOST',
                                                                   defaults.KAFKA_DEFAULTS_HOST))
